@@ -3,7 +3,7 @@ import lab as B
 from matrix import Zero
 
 # noinspection PyUnresolvedReferences
-from ..util import allclose, check_un_op, dense1
+from ..util import approx, check_un_op, dense1
 
 
 def test_zeros(dense1):
