@@ -2,7 +2,6 @@ import lab as B
 import pytest
 
 from matrix import Dense, Diagonal, structured
-
 # noinspection PyUnresolvedReferences
 from .util import (
     AssertDenseWarning,
@@ -27,6 +26,7 @@ def test_dispatch(dense1, dense2):
     assert isinstance(dense1.__rtruediv__(dense2), Dense)
     assert isinstance(dense1 ** 2, Dense)
     assert isinstance(dense1 @ dense2, Dense)
+    assert isinstance(dense1.__rmatmul__(dense2), Dense)
 
 
 def test_properties(dense1):
@@ -36,9 +36,13 @@ def test_properties(dense1):
 
 
 def test_dense_formatting():
-    assert str(Dense(B.ones(3, 3))) == "<dense matrix: shape=3x3, dtype=float64>"
     assert (
-        repr(Dense(B.ones(3, 3))) == "<dense matrix: shape=3x3, dtype=float64\n"
+        str(Dense(B.ones(3, 3)))
+        == "<dense matrix: batch=(), shape=(3, 3), dtype=float64>"
+    )
+    assert (
+        repr(Dense(B.ones(3, 3))) == ""
+        "<dense matrix: batch=(), shape=(3, 3), dtype=float64\n"
         " mat=[[1. 1. 1.]\n"
         "      [1. 1. 1.]\n"
         "      [1. 1. 1.]]>"
@@ -64,13 +68,19 @@ def test_conversion_to_dense(diag1):
     assert isinstance(Dense(diag1).mat, B.Numeric)
 
 
+def test_construction_from_vector():
+    vec = B.randn(3)
+    dense = Dense(vec)
+    approx(B.dense(dense), vec[:, None])
+
+
 def test_indexing_dense(dense1):
-    approx(dense1[2], B.dense(dense1)[2])
+    approx(dense1[..., 2, :], B.dense(dense1)[..., 2, :])
 
 
 def test_indexing_diag(diag1):
     with AssertDenseWarning("indexing into <diagonal>"):
-        approx(diag1[2], B.dense(diag1)[2])
+        approx(diag1[..., 2, :], B.dense(diag1)[..., 2, :])
 
 
 def test_squeeze_dense(dense_bc):
@@ -89,4 +99,8 @@ def test_flatten_dense(dense_bc):
 
 
 def test_diagonal_dense(dense_bc):
+    # The behaviour of `a.diagonal()` is different for dense matrices when a batch
+    # dimension is present.
+    if B.shape_batch(dense_bc) != ():
+        return
     check_un_op(lambda a: a.diagonal(), dense_bc)
